==> release-plz-v0.3.80.tar.gz: release-plz-release-plz-v0.3.80/website/src/pages/pricing.md <==
# Pricing

Just kidding, Release-plz is free and open-source. 💫

However, maintaining Release-plz requires a lot of effort.
If you find Release-plz valuable to you, consider supporting it.
Here’s how you can help:

- **Spread the Word**: Share your experience with Release-plz on
  [Twitter](https://twitter.com/intent/tweet?text=Release-plz%20is%20awesome%21%20Check%20it%20out%20at%20release-plz.ieni.dev),
  [LinkedIn](https://www.linkedin.com/sharing/share-offsite/?url=release-plz.ieni.dev),
  and other platforms using the `#ReleasePlz` hashtag. 📣
- **Star**: Give Release-plz a star on [GitHub](https://github.com/MarcoIeni/release-plz). ⭐
- **Become a Sponsor**: Your financial support helps to dedicate more time to improve
  Release-plz and develop new features. Sponsor Release-plz development on
  [GitHub](https://github.com/sponsors/MarcoIeni). ❤️
- **Contribute**: Get involved by fixing
  [issues](https://github.com/MarcoIeni/release-plz/issues). 🚀

## 🏢 Companies

If you are using Release-plz at your organization to improve your engineering team's productivity,
please reflect on the hours Release-plz saves your team every month
and consider
investing a portion of these savings to [sponsor](https://github.com/sponsors/MarcoIeni) the author.

By sponsoring, you're enabling the author to focus more on the development of Release-plz, ensuring
it remains sustainable, up-to-date and secure.

## 📬 Stay Updated

Stay updated on Release-plz news by following the author on
[Twitter](https://twitter.com/MarcoIeni), [GitHub](https://github.com/MarcoIeni),
[LinkedIn](https://linkedin.com/in/MarcoIeni),
[Mastodon](https://hachyderm.io/@MarcoIeni) and [YouTube](https://www.youtube.com/MarcoIeni).

==> release-plz-v0.3.118.tar.gz: release-plz-release-plz-v0.3.118/website/src/pages/pricing.md <==
# Pricing

Just kidding, Release-plz is free and open-source. 💫

However, maintaining Release-plz requires a lot of effort.
If you find Release-plz valuable to you, consider supporting it.
Here’s how you can help:

- **Spread the Word**: Share your experience with Release-plz on
  [Twitter](https://twitter.com/intent/tweet?text=Release-plz%20is%20awesome%21%20Check%20it%20out%20at%20release-plz.dev),
  [LinkedIn](https://www.linkedin.com/sharing/share-offsite/?url=release-plz.dev),
  and other platforms using the `#ReleasePlz` hashtag. 📣
- **Star**: Give Release-plz a star on [GitHub](https://github.com/release-plz/release-plz). ⭐
- **Become a Sponsor**: Your financial support helps to dedicate more time to improve
  Release-plz and develop new features. Sponsor Release-plz development on
  [GitHub](https://github.com/sponsors/MarcoIeni). ❤️
- **Contribute**: Get involved by fixing
  [issues](https://github.com/release-plz/release-plz/issues). 🚀

## 🏢 Companies

If you are using Release-plz at your organization to improve your engineering team's productivity,
please reflect on the hours Release-plz saves your team every month
and consider
investing a portion of these savings to [sponsor](https://github.com/sponsors/MarcoIeni) the author.

By sponsoring, you're enabling the author to focus more on the development of Release-plz, ensuring
it remains sustainable, up-to-date and secure.

## 📬 Stay Updated

Stay updated on Release-plz news by following the author on
[Twitter](https://twitter.com/MarcoIeni), [GitHub](https://github.com/MarcoIeni),
[LinkedIn](https://linkedin.com/in/MarcoIeni),
[Mastodon](https://hachyderm.io/@MarcoIeni) and [YouTube](https://www.youtube.com/MarcoIeni).
